@@ -1,7 +1,7 @@
 /*
  *      backendgvfs.h
  *
- *      Copyright 2008-2009 Enrico Tröger <enrico(at)xfce(dot)org>
+ *      Copyright 2008-2010 Enrico Tröger <enrico(at)xfce(dot)org>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -86,13 +86,13 @@ enum
 
 
 GType				gigolo_backend_gvfs_get_type					(void);
-GigoloBackendGVFS*	gigolo_backend_gvfs_new							(GtkListStore *store);
+GigoloBackendGVFS*	gigolo_backend_gvfs_new							(void);
 
 gboolean			gigolo_backend_gvfs_is_mount					(gpointer mount);
 void				gigolo_backend_gvfs_get_name_and_uri_from_mount	(gpointer mount, gchar **name, gchar **uri);
 
-gboolean			gigolo_backend_gvfs_mount_volume				(GigoloBackendGVFS *backend, gpointer vol);
-void				gigolo_backend_gvfs_unmount_mount				(GigoloBackendGVFS *backend, gpointer mount);
+gboolean			gigolo_backend_gvfs_mount_volume				(GigoloBackendGVFS *backend, GtkWindow *window, gpointer vol);
+void				gigolo_backend_gvfs_unmount_mount				(GigoloBackendGVFS *backend, gpointer mount, GtkWindow *parent);
 
 void				gigolo_backend_gvfs_mount_uri					(GigoloBackendGVFS *backend,
 																	 const gchar *uri,
@@ -102,14 +102,14 @@ void				gigolo_backend_gvfs_mount_uri					(GigoloBackendGVFS *backend,
 
 gchar*				gigolo_backend_gvfs_get_volume_identifier		(gpointer volume);
 
-gchar**				gigolo_backend_gvfs_get_smb_shares				(const gchar *hostname,
-																	 const gchar *user,
-																	 const gchar *domain);
-
 void				gigolo_backend_gvfs_browse_network				(GigoloBackendGVFS *backend,
 																	 GtkWindow *parent,
 																	 GtkTreeStore *store);
 
+void				gigolo_backend_gvfs_browse_host					(GigoloBackendGVFS *backend,
+																	 GtkWindow *parent,
+																	 const gchar *hostname);
+
 const gchar *const* gigolo_backend_gvfs_get_supported_uri_schemes	(void);
 
 gboolean			gigolo_backend_gvfs_is_scheme_supported			(const gchar *scheme);
