@@ -1,7 +1,7 @@
 /*
  *      window.c
  *
- *      Copyright 2008-2009 Enrico Tröger <enrico(at)xfce(dot)org>
+ *      Copyright 2008-2010 Enrico Tröger <enrico(at)xfce(dot)org>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -250,7 +250,11 @@ void gigolo_window_mount_from_bookmark(GigoloWindow *window, GigoloBookmark *boo
 	if (show_dialog)
 	{
 		const gchar *name = gigolo_bookmark_get_name(bookmark);
-		gchar *label = g_strdup_printf(_("Connecting to \"%s\""), (name != NULL) ? name : uri);
+		gchar *label;
+
+		if (name == NULL || gigolo_str_equal(name, GIGOLO_BOOKMARK_NAME_NONE))
+			name = uri;
+		label = g_strdup_printf(_("Connecting to \"%s\""), name);
 
 		dialog = gigolo_mount_dialog_new(GTK_WINDOW(window), label);
 		gtk_widget_show_all(dialog);
@@ -419,11 +423,11 @@ static void action_about_cb(G_GNUC_UNUSED GtkAction *action, GigoloWindow *windo
 		"authors", authors,
 		"logo-icon-name", gigolo_get_application_icon_name(),
 		"comments", _("A simple frontend to easily connect to remote filesystems"),
-		"copyright", _("Copyright 2008-2009 Enrico Tröger"),
+		"copyright", _("Copyright 2008-2010 Enrico Tröger"),
 		"website", "http://www.uvena.de/gigolo/",
 		"version", VERSION,
 		"translator-credits", _("translator-credits"),
-		"license",  "Copyright 2008-2009 Enrico Tröger <enrico@xfce.org>\n\n"
+		"license",  "Copyright 2008-2010 Enrico Tröger <enrico@xfce.org>\n\n"
 					"This program is free software; you can redistribute it and/or modify\n"
 					"it under the terms of the GNU General Public License as published by\n"
 					"the Free Software Foundation; version 2 of the License.\n"
@@ -500,7 +504,11 @@ static void action_copy_uri_cb(G_GNUC_UNUSED GtkAction *action, GigoloWindow *wi
 
 			b = gigolo_settings_get_bookmark_by_uri(priv->settings, uri);
 			if (b != NULL)
-				setptr(uri, g_build_filename(uri, gigolo_bookmark_get_folder(b), NULL));
+			{
+				gchar *folder = gigolo_bookmark_get_folder_expanded(b);
+				setptr(uri, g_build_filename(uri, folder, NULL));
+				g_free(folder);
+			}
 
 			gtk_clipboard_set_text(gtk_clipboard_get(gdk_atom_intern("CLIPBOARD", FALSE)), uri, -1);
 
@@ -536,15 +544,22 @@ static void action_open_cb(G_GNUC_UNUSED GtkAction *action, GigoloWindow *window
 			gigolo_backend_gvfs_get_name_and_uri_from_mount(mnt, NULL, &uri);
 			b = gigolo_settings_get_bookmark_by_uri(priv->settings, uri);
 			if (b != NULL)
-				setptr(uri, g_build_filename(uri, gigolo_bookmark_get_folder(b), NULL));
+			{
+				gchar *folder = gigolo_bookmark_get_folder_expanded(b);
+				setptr(uri, g_build_filename(uri, folder, NULL));
+				g_free(folder);
+			}
 			/* escape spaces and similar */
 			setptr(uri, g_uri_unescape_string(uri, G_URI_RESERVED_CHARS_ALLOWED_IN_USERINFO));
 
 			cmd = g_strconcat(file_manager, " \"", uri, "\"", NULL);
 			if (! g_spawn_command_line_async(cmd, &error))
 			{
-				verbose("%s", error->message);
+				gchar *msg = g_strdup_printf(_("The command '%s' failed"), cmd);
+				gigolo_message_dialog(window, GTK_MESSAGE_ERROR, _("Error"), msg, error->message);
+				verbose("%s: %s", msg, error->message);
 				g_error_free(error);
+				g_free(msg);
 			}
 
 			g_free(cmd);
@@ -668,7 +683,7 @@ static void mounts_changed_cb(G_GNUC_UNUSED GigoloBackendGVFS *backend, GigoloWi
 static void mount_operation_failed_cb(G_GNUC_UNUSED GigoloBackendGVFS *backend, const gchar *message,
 								   const gchar *error_message, GigoloWindow *window)
 {
-	gigolo_message_dialog((gpointer) window, GTK_MESSAGE_ERROR, _("Error"), message, error_message);
+	gigolo_message_dialog(window, GTK_MESSAGE_ERROR, _("Error"), message, error_message);
 }
 
 
